import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

typedef void GliaPlayerCreatedCallback(GliaPlayerController controller);

class GliaPlayer extends StatefulWidget {
  static const MethodChannel _channel =
      const MethodChannel('gliaplayer');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<String> initGliaSDK(List<String> adNetworks) async {
    final String sdkInitialized = await _channel.invokeMethod('initGliaSDK', {"adNetworks": adNetworks});
    return sdkInitialized;
  }

  const GliaPlayer({
    Key key,
    this.onGliaPlayerCreated,
  }) : super(key: key);

  final GliaPlayerCreatedCallback onGliaPlayerCreated;

  @override
  State<StatefulWidget> createState() => _GliaPlayerState();
}

class _GliaPlayerState extends State<GliaPlayer>
    with AutomaticKeepAliveClientMixin {
  @override
  bool get wantKeepAlive => true;

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return AndroidView(
        viewType: 'gliaplayer',
        onPlatformViewCreated: _onPlatformViewCreated,
      );
    }
    return Text(
        '$defaultTargetPlatform is not yet supported by the text_view plugin');
  }

  void _onPlatformViewCreated(int id) {
    if (widget.onGliaPlayerCreated == null) {
      return;
    }
    widget.onGliaPlayerCreated(new GliaPlayerController._(id));
  }
}

class GliaPlayerController {
  GliaPlayerController._(int id)
      : _channel = new MethodChannel('gliaplayer');

  final MethodChannel _channel;

  Future<void> load(String slot, String article) async {
    assert(slot != null && article != null);
    return _channel.invokeMethod('load', {"slot": slot, "article": article});
  }
}